==> ejc-probid-api-3.0.0-20220715.062505-4-sources.jar: com/ejianc/business/open/vo/OpenVO.java <==
package com.ejianc.business.open.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 开标记录实体
 *
 * @author generator
 */
public class OpenVO extends BaseVO {
	private static final long serialVersionUID = -1448331746108643114L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private Date registrationDeadline; // 报名截止日期
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bidOpenPlace; // 开标地点
	private String bidOpenAuthorName; // 开标授权人
	private String bidCompanyName; // 招标公司
	private Long sourceBondPayId; // 保证金缴纳id
	private String bondMode; // 保证金形式 0-现金、1-保函
	private BigDecimal bidBondMny; // 投标保证金
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private BigDecimal aValue; // A值
	private BigDecimal gValue; // G值
	private String memo; // 说明

	private List<OpenDetailVO> openDetailList = new ArrayList<>(); // 开标记录-开标记录明细实体

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidOpenPlace() {
		return bidOpenPlace;
	}

	public void setBidOpenPlace(String bidOpenPlace) {
		this.bidOpenPlace = bidOpenPlace;
	}

	public String getBidOpenAuthorName() {
		return bidOpenAuthorName;
	}

	public void setBidOpenAuthorName(String bidOpenAuthorName) {
		this.bidOpenAuthorName = bidOpenAuthorName;
	}

	public String getBidCompanyName() {
		return bidCompanyName;
	}

	public void setBidCompanyName(String bidCompanyName) {
		this.bidCompanyName = bidCompanyName;
	}

	public Long getSourceBondPayId() {
		return sourceBondPayId;
	}

	public void setSourceBondPayId(Long sourceBondPayId) {
		this.sourceBondPayId = sourceBondPayId;
	}

	public String getBondMode() {
		return bondMode;
	}

	public void setBondMode(String bondMode) {
		this.bondMode = bondMode;
	}

	public BigDecimal getBidBondMny() {
		return bidBondMny;
	}

	public void setBidBondMny(BigDecimal bidBondMny) {
		this.bidBondMny = bidBondMny;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public BigDecimal getAValue() {
		return aValue;
	}

	public void setAValue(BigDecimal aValue) {
		this.aValue = aValue;
	}

	public BigDecimal getGValue() {
		return gValue;
	}

	public void setGValue(BigDecimal gValue) {
		this.gValue = gValue;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<OpenDetailVO> getOpenDetailList() {
		return openDetailList;
	}

	public void setOpenDetailList(List<OpenDetailVO> openDetailList) {
		this.openDetailList = openDetailList;
	}
}

==> ejc-probid-api-3.0.0-20220727.060223-60-sources.jar: com/ejianc/business/open/vo/OpenVO.java <==
package com.ejianc.business.open.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 开标记录实体
 *
 * @author generator
 */
public class OpenVO extends BaseVO {
	private static final long serialVersionUID = -1448331746108643114L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = " GMT+8")
	private Date registrationDeadline; // 报名截止日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = " GMT+8")
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bidOpenPlace; // 开标地点
	private String bidOpenAuthorName; // 开标授权人
	private String bidCompanyName; // 招标公司
	private Long sourceBondPayId; // 保证金缴纳id
	private String bondMode; // 保证金形式 0-现金、1-保函
	private String bondModeName; // 保证金形式名称
	private BigDecimal bidBondMny; // 投标保证金
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private BigDecimal aValue; // A值
	private BigDecimal gValue; // G值
	private String memo; // 说明

	private List<OpenDetailVO> openDetailList = new ArrayList<>(); // 开标记录-开标记录明细实体

	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidOpenPlace() {
		return bidOpenPlace;
	}

	public void setBidOpenPlace(String bidOpenPlace) {
		this.bidOpenPlace = bidOpenPlace;
	}

	public String getBidOpenAuthorName() {
		return bidOpenAuthorName;
	}

	public void setBidOpenAuthorName(String bidOpenAuthorName) {
		this.bidOpenAuthorName = bidOpenAuthorName;
	}

	public String getBidCompanyName() {
		return bidCompanyName;
	}

	public void setBidCompanyName(String bidCompanyName) {
		this.bidCompanyName = bidCompanyName;
	}

	public Long getSourceBondPayId() {
		return sourceBondPayId;
	}

	public void setSourceBondPayId(Long sourceBondPayId) {
		this.sourceBondPayId = sourceBondPayId;
	}

	public String getBondMode() {
		return bondMode;
	}

	public void setBondMode(String bondMode) {
		this.bondMode = bondMode;
	}

	public String getBondModeName() {
		return bondModeName;
	}

	public void setBondModeName(String bondModeName) {
		this.bondModeName = bondModeName;
	}

	public BigDecimal getBidBondMny() {
		return bidBondMny;
	}

	public void setBidBondMny(BigDecimal bidBondMny) {
		this.bidBondMny = bidBondMny;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public BigDecimal getaValue() {
		return aValue;
	}

	public void setaValue(BigDecimal aValue) {
		this.aValue = aValue;
	}

	public BigDecimal getgValue() {
		return gValue;
	}

	public void setgValue(BigDecimal gValue) {
		this.gValue = gValue;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<OpenDetailVO> getOpenDetailList() {
		return openDetailList;
	}

	public void setOpenDetailList(List<OpenDetailVO> openDetailList) {
		this.openDetailList = openDetailList;
	}
}
